"use strict";

exports.__esModule = true;
exports.default = void 0;

var _hyphenateStyleName = _interopRequireDefault(require("hyphenate-style-name"));

var _normalizeValue = _interopRequireDefault(require("./normalizeValue"));

var _prefixStyles = _interopRequireDefault(require("../../modules/prefixStyles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) 2016-present, Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var createDeclarationString = function createDeclarationString(prop, val) {
  var name = (0, _hyphenateStyleName.default)(prop);
  var value = (0, _normalizeValue.default)(prop, val);

  if (Array.isArray(val)) {
    return val.map(function (v) {
      return name + ":" + v;
    }).join(';');
  }

  return name + ":" + value;
};
/**
 * Generates valid CSS rule body from a JS object
 *
 * createRuleBlock({ width: 20, color: 'blue' });
 * // => 'color:blue;width:20px'
 */


var createRuleBlock = function createRuleBlock(style) {
  var prefixedStyle = (0, _prefixStyles.default)(style);
  return Object.keys(prefixedStyle).map(function (prop) {
    return createDeclarationString(prop, prefixedStyle[prop]);
  }) // put short-form and vendor prefixed properties first
  .sort().join(';');
};

var _default = createRuleBlock;
exports.default = _default;
module.exports = exports.default;